@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 #
 #  Copyright (C) 2001-2004 by MATSUMURA Namihiko <nie@counterghost.net>
-#  Copyright (C) 2004-2016 by Shyouzou Sugitani <shy@users.osdn.me>
+#  Copyright (C) 2004-2018 by Shyouzou Sugitani <shy@users.osdn.me>
 #
 #  This program is free software; you can redistribute it and/or modify it
 #  under the terms of the GNU General Public License (version 2) as
@@ -57,25 +57,25 @@ module NGM
       @url = {}
       @cgi = {}
       @datadir = datadir
-      FileUtils.mkdir_p(@datadir) if not Dir.exists?(@datadir)
+      FileUtils.mkdir_p(@datadir) unless Dir.exists?(@datadir)
       @last_update = '1970-01-01 00:00:00'
       load_MasterList()
     end
 
     # data handling functions
     def get(entry, key)
-      return entry[key]
+      entry[key]
     end
 
     def data
-      return @data
+      @data
     end
 
     # updates etc
     def network_update#(updatehook)
       last_update = @last_update
       @last_update = Time.now.strftime('%Y-%m-%d %H:%M:%S')
-      if not @cgi.empty?
+      unless @cgi.empty?
         priority = @cgi.keys.sort
         url = @cgi[priority[-1]][-1]
       else
@@ -129,7 +129,7 @@ module NGM
     def import_from_fileobj(fileobj)
       line0 = fileobj.readline()
       encoding = get_encoding(line0)
-      if not Encoding.name_list.include?(encoding)
+      unless Encoding.name_list.include?(encoding)
         fail SystemExit('Unsupported encoding {0}'.format(repr(encoding)))
       end
       nest = 0
@@ -148,25 +148,25 @@ module NGM
         next if line.empty?
         line = line.force_encoding(encoding).encode("UTF-8", :invalid => :replace, :undef => :replace)
         m = re_list.match(line)
-        if not m.nil?
+        unless m.nil?
           nest += 1
           next
         end
         m = re_setid.match(line)
-        if not m.nil?
+        unless m.nil?
           nest += 1
           set_id = m[1].to_i
           next
         end
         m = re_set.match(line)
-        if not m.nil?
+        unless m.nil?
           nest -= 1
           new_entry[set_id] = create_entry(node)
           node = []
           next
         end
         m = re_priority.match(line)
-        if m != nil
+        unless m.nil?
           g = m
           priority = g[1].to_i
           url = g[2]
@@ -178,9 +178,9 @@ module NGM
           next
         end
         m = re_misc.match(line)
-        if m != nil
+        unless m.nil?
           g = m
-          if set_id != nil
+          unless set_id.nil?
             key = g[1]
             text = g[2]
             text = text.sub('&apos;', '\'')                
@@ -196,17 +196,18 @@ module NGM
             #               'SakuraPreviewBaseUrl',
             #               'KeroPreviewBaseUrl',
             #               'ArcMD5BaseUrl', 'NGMUpdateBaseUrl']
-            if key == 'LastUpdate'
+            case key
+            when 'LastUpdate'
               @last_update = text
-            elsif key == 'NGMVersion'
+            when 'NGMVersion'
               version = text.to_f
               if version < 0.51
                 return
               else
                 @version = version
               end
-            elsif ['SakuraPreviewBaseUrl', 'KeroPreviewBaseUrl',
-                   'ArcMD5BaseUrl', 'NGMUpdateBaseUrl'].include?(key)
+            when 'SakuraPreviewBaseUrl', 'KeroPreviewBaseUrl',
+                 'ArcMD5BaseUrl', 'NGMUpdateBaseUrl'
               @url[key] = text
             end
           end
@@ -217,7 +218,7 @@ module NGM
 
     def dump_entry(entry, fileobj)
       for key in ELEMENTS
-        if entry.include?(key) and entry[key] != nil
+        if entry.include?(key) and not entry[key].nil?
           text = entry[key]
           text = text.gsub("&", "&amp;")
           text = text.gsub("<", "&lt;")
@@ -281,8 +282,8 @@ module NGM
     def retrieve_image(set_id, side)#, updatehook)
       p = [TYPE[side], '_', set_id, '.png'].join('')
       d = File.join(@datadir, p)
-      if not File.exists?(d)
-        if side == 0
+      unless File.exists?(d)
+        if side.zero?
           url = @url['SakuraPreviewBaseUrl']
         else
           url = @url['KeroPreviewBaseUrl']
@@ -311,7 +312,7 @@ module NGM
         next true # XXX
       end
       @dialog.set_modal(true)
-      @dialog.set_window_position(Gtk::Window::Position::CENTER)
+      @dialog.set_window_position(Gtk::WindowPosition::CENTER)
       label = Gtk::Label.new(label=_('Search for'))
       content_area = @dialog.content_area
       content_area.add(label)
@@ -335,7 +336,7 @@ module NGM
     end
                 
     def get_pattern
-      return @pattern_entry.text
+      @pattern_entry.text
     end
 
     def hide
@@ -343,9 +344,7 @@ module NGM
     end
 
     def show(default: nil)
-      if default != nil
-        set_pattern(default)
-      end
+      set_pattern(default) unless default.nil?
       @dialog.show()
     end
 
@@ -360,11 +359,12 @@ module NGM
     end
 
     def response(widget, response)
-      if response == Gtk::ResponseType::OK
+      case response
+      when Gtk::ResponseType::OK
         ok()
-      elsif response == Gtk::ResponseType::CANCEL
+      when Gtk::ResponseType::CANCEL
         cancel()
-      elsif response == Gtk::ResponseType::DELETE_EVENT
+      when Gtk::ResponseType::DELETE_EVENT
         cancel()
       else
         # should not reach here
@@ -379,72 +379,6 @@ module NGM
 
     def initialize
       @parent = nil
-      @ui_info = "
-        <ui>
-          <menubar name='MenuBar'>
-            <menu action='FileMenu'>
-              <menuitem action='Search'/>
-              <menuitem action='Search Forward'/>
-              <separator/>
-              <menuitem action='Settings'/>
-              <separator/>
-              <menuitem action='DB Network Update'/>
-              <separator/>
-              <menuitem action='Close'/>
-            </menu>
-            <menu action='ViewMenu'>
-              <menuitem action='Mask'/>
-              <menuitem action='Reset to Default'/>
-              <menuitem action='Show All'/>
-            </menu>
-            <menu action='ArchiveMenu'>
-            </menu>
-            <menu action='HelpMenu'>
-            </menu>
-          </menubar>
-        </ui>"
-      @entries = [
-                  [ 'FileMenu', nil, _('_File') ],
-                  [ 'ViewMenu', nil, _('_View') ],
-                  [ 'ArchiveMenu', nil, _('_Archive') ],
-                  [ 'HelpMenu', nil, _('_Help') ],
-                  [ 'Search', nil,                  # name, stock id
-                    _('Search(_F)'), '<control>F',   # label, accelerator
-                    'Search',                        # tooltip
-                    lambda {|a, b| open_search_dialog()} ],
-                  [ 'Search Forward', nil,
-                    _('Search Forward(_S)'), 'F3',
-                    nil,
-                    lambda {|a, b| search_forward()} ],
-                  [ 'Settings', nil,
-                    _('Settings(_O)'), nil,
-                    nil,
-                    lambda {|a, b| @parent.handle_request(
-                                                          'NOTIFY', 'open_preference_dialog')} ],
-                  [ 'DB Network Update', nil,
-                    _('DB Network Update(_N)'), nil,
-                    nil,
-                    lambda {|a, b| network_update()} ],
-                  [ 'Close', nil,
-                    _('Close(_X)'), nil,
-                    nil,
-                    lambda {|a, b| close()} ],
-                  [ 'Mask', nil,
-                    _('Mask(_M)'), nil,
-                    nil,
-                    lambda {|a, b| @parent.handle_request(
-                                                          'NOTIFY', 'open_mask_dialog')} ],
-                  [ 'Reset to Default', nil,
-                    _('Reset to Default(_Y)'), nil,
-                    nil,
-                    lambda {|a, b| @parent.handle_request(
-                                                          'NOTIFY', 'reset_to_default')} ],
-                  [ 'Show All', nil,
-                    _('Show All(_Z)'), nil,
-                    nil,
-                    lambda {|a, b| @parent.handle_request(
-                                                          'NOTIFY', 'show_all')} ],
-                  ]
       @opened = false
       @textview = [nil, nil]
       @darea = [nil, nil]
@@ -476,9 +410,7 @@ module NGM
             event_type, event, *arglist)
         end
       end
-      if event_type == 'GET'
-        return result
-      end
+      return result if event_type == 'GET'
     end
 
     def create_dialog
@@ -488,22 +420,79 @@ module NGM
       @window.signal_connect('delete_event') do |a|
         next close()
       end
-      @window.set_window_position(Gtk::Window::Position::CENTER)
+      @window.set_window_position(Gtk::WindowPosition::CENTER)
       @window.gravity = Gdk::Gravity::CENTER
-      actions = Gtk::ActionGroup.new('Actions')
-      actions.add_actions(@entries)
-      ui = Gtk::UIManager.new()
-      ui.insert_action_group(actions, 0)
-      @window.add_accel_group(ui.accel_group)
-      begin
-        mergeid = ui.add_ui(@ui_info)
-      rescue => e #except GObject.GError as msg:
-        Logging::Logging.error('building menus failed: ' + e.message)
+      accelgroup = Gtk::AccelGroup.new()
+      @window.add_accel_group(accelgroup)
+      menubar = Gtk::MenuBar.new()
+      item = Gtk::MenuItem.new(:label => _('_File'), :use_underline => true)
+      menubar.add(item)
+      menu = Gtk::Menu.new()
+      item.set_submenu(menu)
+      item = Gtk::MenuItem.new(:label => _('Search(_F)'), :use_underline => true)
+      item.signal_connect('activate') do |a, b|
+        open_search_dialog()
       end
+      item.add_accelerator('activate', accelgroup, Gdk::Keyval::KEY_f,
+                           Gdk::ModifierType::CONTROL_MASK,
+                           Gtk::AccelFlags::VISIBLE)
+      menu.add(item)
+      item = Gtk::MenuItem.new(:label => _('Search Forward(_S)'), :use_underline => true)
+      item.signal_connect('activate') do |a, b|
+        search_forward()
+      end
+      item.add_accelerator('activate', accelgroup, Gdk::Keyval::KEY_F3,
+                           nil,
+                           Gtk::AccelFlags::VISIBLE)
+      menu.add(item)
+      item = Gtk::SeparatorMenuItem.new()
+      menu.add(item)
+      item = Gtk::MenuItem.new(:label => _('Settings(_O)'), :use_underline => true)
+      item.signal_connect('activate') do |a, b|
+        @parent.handle_request('NOTIFY', 'open_preference_dialog')
+      end
+      menu.add(item)
+      item = Gtk::SeparatorMenuItem.new()
+      menu.add(item)
+      item = Gtk::MenuItem.new(:label => _('DB Network Update(_N)'), :use_underline => true)
+      item.signal_connect('activate') do |a, b|
+        network_update()
+      end
+      menu.add(item)
+      item = Gtk::SeparatorMenuItem.new()
+      menu.add(item)
+      item = Gtk::MenuItem.new(:label => _('Close(_X)'), :use_underline => true)
+      item.signal_connect('activate') do |a, b|
+        close()
+      end
+      menu.add(item)
+      item = Gtk::MenuItem.new(:label => _('_View'), :use_underline => true)
+      menu = Gtk::Menu.new
+      item.set_submenu(menu)
+      item = Gtk::MenuItem.new(:label => _('Mask(_M)'), :use_underline => true)
+      item.signal_connect('activate') do |a, b|
+        @parent.handle_request('NOTIFY', 'open_mask_dialog')
+      end
+      menu.add(item)
+      item = Gtk::MenuItem.new(:label => _('Reset to Default(_Y)'), :use_underline => true)
+      item.signal_connect('activate') do |a, b|
+        @parent.handle_request('NOTIFY', 'reset_to_default')
+      end
+      menu.add(item)
+      item = Gtk::MenuItem.new(:label => _('Show All(_Z)'), :use_underline => true)
+      item.signal_connect('activate') do |a, b|
+        @parent.handle_request('NOTIFY', 'show_all')
+      end
+      menu.add(item)
+      item = Gtk::MenuItem.new(:label => _('_Archive'), :use_underline => true)
+      menubar.add(item)
+      item = Gtk::MenuItem.new(:label => _('_Help'), :use_underline => true)
+      menubar.add(item)
+      menubar.show_all
       vbox = Gtk::Box.new(orientation=Gtk::Orientation::VERTICAL)
       @window.add(vbox)
       vbox.show()
-      vbox.pack_start(ui.get_widget('/MenuBar'), :expand => false, :fill => false, :padding => 0)
+      vbox.pack_start(menubar, :expand => false, :fill => false, :padding => 0)
       separator = Gtk::Separator.new(:horizontal)
       vbox.pack_start(separator, :expand => false, :fill => true, :padding => 0)
       separator.show()
@@ -517,7 +506,7 @@ module NGM
       @info_area = create_info_area()
       hbox.pack_start(@info_area, :expand => false, :fill => true, :padding => 10)
       box = Gtk::ButtonBox.new(orientation=Gtk::Orientation::HORIZONTAL)
-      box.set_layout_style(Gtk::ButtonBox::Style::SPREAD)
+      box.set_layout_style(Gtk::ButtonBoxStyle::SPREAD)
       vbox.pack_start(box, :expand => false, :fill => true, :padding => 4)
       box.show()
       button = Gtk::Button.new(:label => _('Previous'))
@@ -553,7 +542,7 @@ module NGM
     end
 
     def search(word)
-      if word != nil and not word.empty?
+      unless word.nil? or word.empty?
         @search_word = word
         if @parent.handle_request('GET', 'search', word)
           update()
@@ -564,7 +553,7 @@ module NGM
     end
 
     def search_forward
-      if not @search_word.empty?
+      unless @search_word.empty?
         if @parent.handle_request('GET', 'search_forward', @search_word)
           update()
         else
@@ -606,7 +595,7 @@ module NGM
     end
 
     def redraw(widget, cr, side)
-      if @surface[side] != nil
+      unless @surface[side].nil?
         cr.set_source(@surface[side], 0, 0)
         cr.set_operator(Cairo::OPERATOR_OVER)
         cr.paint()
@@ -618,7 +607,7 @@ module NGM
 
     def update_surface_area
       for side in [0, 1]
-        if side == 0
+        if side.zero?
           target = 'SakuraName'
         else
           target = 'KeroName'
@@ -629,15 +618,16 @@ module NGM
         filename = @parent.handle_request('GET', 'get_image_filename', side)
         darea = @darea[side]
         darea.realize()
-        if filename != nil and not filename.empty?
+        unless filename.nil? or filename.empty?
           begin
             surface = Pix.create_surface_from_file(filename)
           rescue
             surface = nil
-          end
+          else
             w = surface.width
             h = surface.height
             darea.set_size_request(w, h)
+          end
         else
           surface = nil
         end
@@ -651,7 +641,7 @@ module NGM
       vbox.show()
       hbox = Gtk::Box.new(orientation=Gtk::Orientation::HORIZONTAL)
       box = Gtk::ButtonBox.new(orientation=Gtk::Orientation::HORIZONTAL)
-      box.set_layout_style(Gtk::ButtonBox::Style::SPREAD)
+      box.set_layout_style(Gtk::ButtonBoxStyle::SPREAD)
       box.show()
       button = Gtk::Button.new(:label => _('Install'))
       button.signal_connect(
@@ -766,9 +756,7 @@ module NGM
     end
 
     def show
-      if @opened
-        return
-      end
+      return if @opened
       update()
       @window.show()
       @opened = true
@@ -815,18 +803,14 @@ module NGM
           result = @parent.handle_request(event_type, event, *arglist)
         end
       end
-      if event_type == 'GET'
-        return result
-      end
+      return result if event_type == 'GET'
     end
 
     def get(element)
       if @catalog.data.include?(@current)
         entry = @catalog.data[@current]
         text = @catalog.get(entry, element)
-        if text != nil
-          return text
-        end
+        return text unless text.nil?
       end
       return 'No data'
     end
@@ -842,7 +826,7 @@ module NGM
           for element in ['Name', 'SakuraName', 'KeroName',
                           'Author', 'HPTitle']
             text = @catalog.get(entry, element)
-            if text == nil or text.empty?
+            if text.nil? or text.empty?
               next
             end
             if text.include?(word)
@@ -923,7 +907,7 @@ module NGM
         target_dir = nil
       end
       assert filetype == 'ghost'
-      if target_dir != nil
+      unless target_dir.nil?
         @parent.handle_request('NOTIFY', 'add_sakura', target_dir)
       end
     end
